@@ -34,6 +34,22 @@ Given 'a cookbook attributes file with a do block that takes arguments' do
   }
 end
 
+Given 'a cookbook attributes file that sets an attribute to have line break' do
+  write_attributes %q{
+    default['foo']['bar']['baz'][
+     'bing']['blonk'] = 'stupendous'
+  }
+end
+
+Given 'a cookbook attributes file that sets an attribute to have line break and arguments' do
+  write_attributes %q{
+    %w{ foo bar }.each do |baz|
+      default['foo']["bing_#{baz}"][
+        'blonk'] = baz
+    end
+  }
+end
+
 Given /^a cookbook (attributes|recipe) file with assignment (.*)$/ do |type, assignment|
   if type == 'attributes'
     write_attributes assignment
@@ -42,7 +58,7 @@ Given /^a cookbook (attributes|recipe) file with assignment (.*)$/ do |type, ass
   end
 end
 
-Given "a cookbook recipe that contains a group resource that uses the 'system' attribute" do
+Given "a cookbook recipe that contains a group resource that uses the 'system' bool attribute" do
   write_recipe %q{
     group "senge" do
       system true
@@ -50,6 +66,14 @@ Given "a cookbook recipe that contains a group resource that uses the 'system' a
   }
 end
 
+Given "a cookbook recipe that contains a user resource that uses the 'system' string attribute" do
+  write_recipe %q{
+    user "foo" do
+      system "bar"
+    end
+  }
+end
+
 Given /^a cookbook recipe that declares (too many )?execute resources varying only in the command in branching conditionals$/ do |too_many|
   extra_resource = %q{
     execute "bing" do
@@ -93,6 +117,18 @@ Given /^a cookbook recipe that spawns a sub-process with (.*)$/ do |command|
   write_recipe command
 end
 
+Given 'a provider that contains a ruby_block resource that spawns a sub-process with system' do
+  write_provider 'site', %q{
+    action :install do
+      ruby_block "ruby" do
+        block do
+          system "ls"
+        end
+      end
+    end
+  }
+end
+
 Given 'a cookbook recipe with a deploy resource that contains a template resource' do
   write_recipe %q{
     deploy '/foo/bar' do
@@ -203,7 +239,7 @@ Given 'a cookbook provider that declares execute resources varying only in the c
 end
 
 Given /^a cookbook recipe that attempts to perform a search with (.*)$/ do |search_type|
-  recipe_with_search(search_type.include?('subexpression') ? :with_subexpression : search_type.gsub(' ', '_').to_sym)
+  recipe_with_search(search_type.include?('subexpression') ? :with_subexpression : search_type.tr(' ', '_').to_sym)
 end
 
 Given /^a cookbook recipe that declares a resource called ([^ ]+) with the condition (.*)(in|outside) a loop$/ do |name,condition,is_loop|
@@ -947,7 +983,7 @@ Given /^a cookbook that declares ([a-z]+) attributes via symbols$/ do |attribute
 end
 
 Given /^a cookbook that does not contain a definition and has (no|a) definitions directory$/ do |has_dir|
-  create_dir 'cookbooks/example/definitions/' unless has_dir == 'no'
+  create_directory 'cookbooks/example/definitions/' unless has_dir == 'no'
   write_recipe %q{
     log "A defining characteristic of this cookbook is that it has no definitions"
   }
@@ -1193,6 +1229,14 @@ Given /^a cookbook with a single recipe that creates a directory resource with (
                         'a literal and interpolated variable' => :literal_and_interpolated_symbol}[path_type])
 end
 
+Given 'a cookbook with a single recipe that logs an interpolated string heredoc' do
+  write_recipe %q(
+    Chef::Log.warn <<-LOG
+      Warning stuff has gone wrong: #{stuff}
+    LOG
+  )
+end
+
 Given 'a cookbook with a single recipe that searches but checks first (alternation) to see if this is server' do
   write_recipe %q{
     if Chef::Config[:solo] || we_dont_want_to_use_search
@@ -1275,6 +1319,40 @@ Given /^a cookbook with metadata that (specifies|does not specify) the cookbook
   }
 end
 
+Given /^a cookbook with metadata that (includes|does not include) a maintainer keyword$/ do |includes|
+  write_metadata %Q{
+    #{"maintainer 'A Maintainer'" if includes == 'includes'}
+  }
+end
+
+Given /^a cookbook with metadata that (includes|does not include) a maintainer email$/ do |includes|
+  write_metadata %Q{
+   #{"maintainer_email 'maintainer@example.com'" if includes == 'includes'}
+  }
+end
+
+Given 'a cookbook with metadata that includes a maintainer expression' do
+  write_metadata "maintainer an(expression)"
+end
+
+Given 'a cookbook with metadata that includes a maintainer email expression' do
+  write_metadata "maintainer_email an(expression)"
+end
+
+Given /^a cookbook with metadata that (includes|does not include) a recommends keyword$/ do |includes|
+  write_metadata %Q{
+    depends "bar"
+    #{"recommends 'foo'" if includes == 'includes'}
+  }
+end
+
+Given /^a cookbook with metadata that (includes|does not include) a suggests keyword$/ do |includes|
+  write_metadata %Q{
+    depends "bar"
+    #{"suggests 'foo'" if includes == 'includes'}
+  }
+end
+
 Given /^a directory that contains a role file ([^ ]+) in (json|ruby) that defines role name (.*)$/ do |file_name, format, role_name|
   role(:role_name => %Q{"#{role_name}"}, :file_name => file_name, :format => format.to_sym)
 end
@@ -1653,19 +1731,21 @@ Given 'a recipe that installs a gem with 5 retries' do
   }
 end
 
-Given 'a recipe that installs a package with yum specifying the architecture' do
+Given 'a recipe that creates a raid array with mdadm specifying layout' do
   write_recipe %q{
-    yum_package "foo" do
-      arch "x86_64"
-      action :install
+    mdadm '/dev/md0' do
+      devices [ '/dev/sda', '/dev/sdb', '/dev/sdc', '/dev/sdd' ]
+      level 5
+      layout 'left-asymmetric'
+      action [ :create, :assemble ]
     end
   }
 end
 
-Given 'a recipe that reconfigures a package' do
+Given 'a recipe that tries to mask a systemd service' do
   write_recipe %q{
-    apt_package "foo" do
-      action :reconfig
+    service 'foo' do
+       action :mask
     end
   }
 end
@@ -1708,7 +1788,7 @@ Given /^a template directory that contains a binary file (.*) that is not valid
   template_dir = 'cookbooks/example/templates/default'
   write_recipe ''
   write_file "#{template_dir}/innocent_template.erb", '<%= hello %>'
-  File.open("#{current_dir}/#{template_dir}/#{filename}", 'wb'){|f| f.putc(0x93)}
+  File.open("#{expand_path('.')}/#{template_dir}/#{filename}", 'wb'){|f| f.putc(0x93)}
 end
 
 Given 'each role directory has a role with a name that does not match the containing file name' do
@@ -1755,8 +1835,8 @@ end
 
 When /^I check the cookbook specifying ([^ ]+) as the Chef version$/ do |version|
   options = ['-c', version, 'cookbooks/example']
-  in_current_dir do
-    options = ['-I', 'rules/test.rb'] + options if Dir.exists?('rules')
+  cd '.' do
+    options = ['-I', 'rules/test.rb'] + options if Dir.exist?('rules')
   end
   run_lint(options)
 end
@@ -1890,7 +1970,7 @@ end
 
 When /^I run it on the command line with the (?:unimplemented |)([^ ]+) option( with an argument)?$/ do |option, with_argument|
   options = []
-  if option.match(/\-\w$/)
+  if option =~ /\-\w$/
     options << option
   else
     options << "--#{option}"
@@ -1929,6 +2009,10 @@ Then /^the bare attribute keys warning 044 should not be displayed against the (
   expect_warning 'FC044', {:expect_warning => false, :line => 2, :file_type => :attributes}
 end
 
+Then /^the bare attribute keys warning 044 should not be displayed against the new line$/ do
+  expect_warning 'FC044', {:expect_warning => false, :line => 3, :file_type => :attributes}
+end
+
 Then 'the execute resource used to run git commands warning 040 should be displayed against the last resource' do
   expect_warning 'FC040', {:line => 7}
 end
@@ -1952,6 +2036,14 @@ Then 'the prefer mixlib shellout warning 048 should not be displayed against the
   expect_warning 'FC048', {:expect_warning => false, :line => 2}
 end
 
+Then 'the prefer mixlib shellout warning 048 should not be displayed against the user resource' do
+  expect_warning 'FC048', {:expect_warning => false, :line => 2}
+end
+
+Then 'the prefer mixlib shellout warning 048 should be displayed against the ruby_block resource' do
+  expect_warning('FC048', :file_type => :provider, :line => 4)
+end
+
 Then /^the role name does not match file name warning 049 should( not)? be shown( against the second name)?$/ do |not_shown, second|
   expect_warning 'FC049', {:expect_warning => ! not_shown,
                            :file => 'roles/webserver.rb', :line => second ? 2 : 1}
@@ -2009,7 +2101,7 @@ Then /^the warning ([0-9]+ )?should (not )?be (?:displayed|shown)$/ do |warning,
   expect_warning code, {:expect_warning => should_not.nil?}
 end
 
-Then /^the (?:[a-zA-Z \-_]+) warning ([0-9]+) should (not )?be displayed(?: against the (attributes|libraries|definition|metadata|provider|resource|README.md|README.rdoc) file)?( below)?$/ do |code, no_display, file, warning_only|
+Then /^the (?:[a-zA-Z \-_]+) warning ([0-9]+) should (not )?be displayed(?: against the (attributes|libraries|definition|metadata|provider|resource|README.md|README.rdoc) file)?( below)?(?: on (?:(any line)|(?:line ([0-9]+))))?$/ do |code, no_display, file, warning_only, any_line, line|
   options = {}
   options[:expect_warning] = no_display != 'not '
   unless file.nil?
@@ -2021,6 +2113,13 @@ Then /^the (?:[a-zA-Z \-_]+) warning ([0-9]+) should (not )?be displayed(?: agai
   end
   options[:line] = 3 if code == '018' and options[:expect_warning]
   options[:line] = 2 if ['021', '022'].include?(code)
+
+  if any_line
+    options[:line] = nil
+  else
+    options[:line] = line unless line.nil?
+  end
+
   options[:warning_only] = ! warning_only.nil?
   expect_warning("FC#{code}", options)
 end
@@ -2042,7 +2141,7 @@ Then /the build status should be (successful|failed)$/ do |build_outcome|
 end
 
 Then /^the build will (succeed|fail) with (?:no )?warnings(.*)$/ do |build_outcome, warnings|
-  assert_build_result(build_outcome == 'succeed', warnings.gsub(' ', '').split(','))
+  assert_build_result(build_outcome == 'succeed', warnings.delete(' ').split(','))
 end
 
 Then 'the check for server warning 003 should not be displayed against the condition' do
@@ -2202,6 +2301,10 @@ Then /^the unrecognised attribute warning 009 should be (true|false)$/ do |shown
   shown == 'true' ? expect_warning('FC009') : expect_no_warning('FC009')
 end
 
+Then /^the invalid resource action warning 038 should be (true|false)$/ do |shown|
+  shown == 'true' ? expect_warning('FC038') : expect_no_warning('FC038')
+end
+
 Then 'the unrecognised attribute warning 009 should be displayed against the correct resource' do
   expect_warning('FC009', :line => 7)
 end
@@ -2241,3 +2344,192 @@ Given(/^a cookbook with an? (.*) file with an interpolated name$/) do |file_type
   write_definition "apache_site", content if file_type == "definition"
   write_library "lib", content if file_type == "library"
 end
+
+Then /^the metadata missing maintainer warning 055 should be (shown|not shown) against the metadata file$/ do |show_warning|
+  expect_warning('FC055', :file => 'metadata.rb', :expect_warning => show_warning == 'shown')
+end
+
+Then /^the metadata missing maintainer email warning 056 should be (shown|not shown) against the metadata file$/ do |show_warning|
+  expect_warning('FC056', :file => 'metadata.rb', :expect_warning => show_warning == 'shown')
+end
+
+Then /^the metadata using suggests warning 052 should be (shown|not shown) against the metadata file$/ do |show_warning|
+  expect_warning('FC052', :file => "metadata.rb", :line => 2, :expect_warning => show_warning == 'shown')
+end
+
+Then /^the metadata using recommends warning 053 should be (shown|not shown) against the metadata file$/ do |show_warning|
+  expect_warning('FC053', :file => "metadata.rb", :line => 2, :expect_warning => show_warning == 'shown')
+end
+
+Given /^a cookbook that contains a LWRP provider (with|without) use_inline_resources( and uses def action_create)?$/ do |with_use_inline_resources, uses_def|
+  write_resource("site", %q{
+    actions :create
+    attribute :name, :kind_of => String, :name_attribute => true
+  })
+  provider_file = ""
+  if with_use_inline_resources == 'with'
+    provider_file += %q{
+      use_inline_resources
+    }
+  end
+  if uses_def
+    provider_file += %q{
+      def action_create
+    }
+  else
+    provider_file += %q{
+      action :create do
+    }
+  end
+  provider_file += %q{
+       file "/tmp/foo.txt"
+    end
+  }
+  write_provider("site", provider_file)
+end
+
+Given /^a cookbook that contains a library provider (with|without) use_inline_resources( and uses def action_create)?$/ do |with_use_inline_resources, uses_def|
+  library_file = %q{
+    class MyResources
+      class Site < Chef::Resource::LWRPBase
+        provides :site
+        resource_name :site
+        actions :create
+        attribute :name, :kind_of => String, :name_attribute => true
+      end
+    end
+
+    class MyProviders
+      class Site < Chef::Provider::LWRPBase
+        provides :site
+  }
+  if with_use_inline_resources == 'with'
+    library_file += %q{
+        use_inline_resources
+    }
+  end
+  if uses_def
+    library_file += %q{
+          def action_create
+    }
+  else
+    library_file += %q{
+          action :create do
+    }
+  end
+  library_file += %q{
+          file "/tmp/foo.txt"
+        end
+      end
+    end
+  }
+  write_library('lib', library_file)
+end
+
+Given /^a cookbook that contains a library resource$/ do
+  library_file = %q{
+    class MyResources
+      class Site < Chef::Resource::LWRPBase
+        provides :site
+        resource_name :site
+        actions :create
+        attribute :name, :kind_of => String, :name_attribute => true
+      end
+    end
+  }
+  write_library('lib', library_file)
+end
+
+Given 'a cookbook with metadata that includes the version keyword and a valid version string' do
+  write_metadata %Q{version '1.2.3'}
+end
+
+Given 'a cookbook with metadata that includes the version keyword and a valid version string with double quotes' do
+  write_metadata %Q{version '1.2.3'}
+end
+
+Given 'a cookbook with metadata that includes the version keyword and a valid x.y version string' do
+  write_metadata %Q{version '1.2'}
+end
+
+Given 'a cookbook with metadata that does not include a version keyword' do
+  write_metadata %Q{
+    name 'test'
+  }
+end
+
+Given 'a cookbook with metadata that includes the version keyword and an invalid version string' do
+  write_metadata %Q{version '1.a.3'}
+end
+
+Given 'a cookbook with metadata that includes the version keyword and an invalid single digit version string' do
+  write_metadata %Q{version '1'}
+end
+
+Given 'a cookbook with metadata that includes the version keyword and an invalid 4 digit version string' do
+  write_metadata %Q{version '1.2.3.4'}
+end
+
+Given 'a cookbook with a metadata version that uses string interpolation' do
+  write_metadata %q{
+    patch = 3
+    version "1.2.#{patch}"
+  }
+end
+
+Given 'a cookbook with a metadata version that is not a string literal' do
+  write_metadata %q{
+    v = "1.2.3"
+    version v
+  }
+end
+
+Given 'a cookbook with a metadata version that is a method call' do
+  write_metadata %q{
+    version magic_version_generator('and its args')
+  }
+end
+
+Given(/^a cookbook with metadata that (includes|does not include) a self dependency$/) do |includes|
+  write_metadata %Q{
+    name 'bar'
+    depends 'baz'
+    #{"depends 'bar'" if includes == 'includes'}
+  }
+end
+
+Then(/^the metadata with self dependency warning 063 should be (shown|not shown) against the metadata file$/) do |show_warning|
+  if show_warning == 'shown'
+    expect_warning('FC063', :file => "metadata.rb", :line => 3, :expect_warning => true)
+  else
+    expect_warning('FC063', :file => "metadata.rb", :expect_warning => false)
+  end
+end
+
+Given(/^a cookbook with metadata that (includes|does not include) a issues_url keyword$/) do |includes|
+  write_metadata %Q{
+    #{"issues_url 'http://github.com/foo/bar_cookbook/issues'" if includes == 'includes'}
+  }
+end
+
+Given(/^a cookbook with metadata that includes a issues_url expression$/) do
+  write_metadata "issues_url an(expression)"
+end
+
+Then(/^the metadata missing issues_url warning 064 should be (shown|not shown) against the metadata file$/) do |show_warning|
+  expect_warning('FC064', :file => 'metadata.rb', :expect_warning => show_warning == 'shown')
+end
+
+Given(/^a cookbook with metadata that (includes|does not include) a source_url keyword$/) do |includes|
+  write_metadata %Q{
+    #{"source_url 'http://github.com/foo/bar_cookbook/'" if includes == 'includes'}
+  }
+end
+
+Then(/^the metadata missing source_url warning 065 should be (shown|not shown) against the metadata file$/) do |show_warning|
+  expect_warning('FC065', :file => 'metadata.rb', :expect_warning => show_warning == 'shown')
+end
+
+Given(/^a cookbook with metadata that includes a source_url expression$/) do
+  write_metadata "source_url an(expression)"
+end
