@@ -28,7 +28,7 @@ module FoodCritic
       'FC012' => 'Use Markdown for README rather than RDoc',
       'FC013' => 'Use file_cache_path rather than hard-coding tmp paths',
       'FC014' => 'Consider extracting long ruby_block to library',
-      'FC015' => 'Consider converting definition to a LWRP',
+      'FC015' => 'Consider converting definition to a Custom Resource',
       'FC016' => 'LWRP does not declare a default action',
       'FC017' => 'LWRP does not notify when updated',
       'FC018' => 'LWRP uses deprecated notification syntax',
@@ -55,13 +55,27 @@ module FoodCritic
       'FC042' => 'Prefer include_recipe to require_recipe',
       'FC043' => 'Prefer new notification syntax',
       'FC044' => 'Avoid bare attribute keys',
-      'FC045' => 'Consider setting cookbook name in metadata',
+      'FC045' => 'Metadata does not contain cookbook name',
       'FC046' => 'Attribute assignment uses assign unless nil',
       'FC047' => 'Attribute assignment does not specify precedence',
       'FC048' => 'Prefer Mixlib::ShellOut',
       'FC049' => 'Role name does not match containing file name',
       'FC050' => 'Name includes invalid characters',
       'FC051' => 'Template partials loop indefinitely',
+      'FC052' => 'Metadata uses the unimplemented "suggests" keyword',
+      'FC053' => 'Metadata uses the unimplemented "recommends" keyword',
+      # FC054 was yanked and is considered reserved, do not reuse it
+      'FC055' => 'Ensure maintainer is set in metadata',
+      'FC056' => 'Ensure maintainer_email is set in metadata',
+      'FC057' => 'Library provider does not declare use_inline_resources',
+      'FC058' => 'Library provider declares use_inline_resources and declares #action_<name> methods',
+      'FC059' => 'LWRP provider does not declare use_inline_resources',
+      'FC060' => 'LWRP provider declares use_inline_resources and declares #action_<name> methods',
+      'FC061' => 'Valid cookbook versions are of the form x.y or x.y.z',
+      'FC062' => 'Cookbook should have version metadata',
+      'FC063' => 'Cookbook incorrectly depends on itself',
+      'FC064' => 'Ensure issues_url is set in metadata',
+      'FC065' => 'Ensure source_url is set in metadata',
       'FCTEST001' => 'Test Rule'
     }
 
@@ -183,6 +197,9 @@ module FoodCritic
         {:short => 'f', :long => 'epic-fail TAGS',
          :description => "Fail the build based on tags. Use 'any' to fail on all warnings."},
 
+        {:short => 'l', :long => 'list',
+         :description => 'List all enabled rules and their descriptions.'},
+
         {:short => 't', :long => 'tags TAGS',
          :description => 'Check against (or exclude ~) rules with the specified tags.'},
 
@@ -273,16 +290,16 @@ module FoodCritic
     #
     # @param [Array] cmd_args The command line arguments.
     def run_lint(cmd_args)
-      in_current_dir do
+      cd '.' do
         show_context = cmd_args.include?('-C')
-        review, @status = FoodCritic::Linter.check(CommandLine.new(cmd_args))
+        review, @status = FoodCritic::Linter.run(CommandLine.new(cmd_args))
         @review =
           if review.nil? || (review.respond_to?(:warnings) && review.warnings.empty?)
             ''
           elsif show_context
             ContextOutput.new.output(review)
           else
-            "#{review.to_s}\n"
+            "#{review}\n"
           end
       end
     end
