@@ -75,26 +75,54 @@ module FoodCritic
       end
     end
 
-    # The name of the cookbook containing the specified file.
-    def cookbook_name(file)
-      fail ArgumentError, 'File cannot be nil or empty' if file.to_s.empty?
-
+    # Support function to retrieve a metadata field
+    def metadata_field(file, field)
       until (file.split(File::SEPARATOR) & standard_cookbook_subdirs).empty? do
         file = File.absolute_path(File.dirname(file.to_s))
       end
       file = File.dirname(file) unless File.extname(file).empty?
-      # We now have the name of the directory that contains the cookbook.
 
-      # We also need to consult the metadata in case the cookbook name has been
-      # overridden there. This supports only string literals.
       md_path = File.join(file, 'metadata.rb')
       if File.exist?(md_path)
-        name = read_ast(md_path).xpath("//stmts_add/
-          command[ident/@value='name']/
+        value = read_ast(md_path).xpath("//stmts_add/
+          command[ident/@value='#{field}']/
           descendant::tstring_content/@value").to_s
-        return name unless name.empty?
+        raise RuntimeError, "Cant read #{field} from #{md_path}" if value.to_s.empty?
+        return value
+      else
+        raise RuntimeError, "Cant find #{md_path}"
       end
-      File.basename(file)
+    end
+
+    # The name of the cookbook containing the specified file.
+    def cookbook_name(file)
+      fail ArgumentError, 'File cannot be nil or empty' if file.to_s.empty?
+
+      # Name is a special case as we want to fallback to the cookbook directory
+      # name if metadata_field fails
+      begin
+        metadata_field(file, 'name')
+      rescue RuntimeError
+        until (file.split(File::SEPARATOR) & standard_cookbook_subdirs).empty? do
+          file = File.absolute_path(File.dirname(file.to_s))
+        end
+        file = File.dirname(file) unless File.extname(file).empty?
+        File.basename(file)
+      end
+    end
+
+    # The maintainer of the cookbook containing the specified file.
+    def cookbook_maintainer(file)
+      fail ArgumentError, 'File cannot be nil or empty' if file.to_s.empty?
+
+      metadata_field(file, 'maintainer')
+    end
+
+    # The maintainer email of the cookbook containing the specified file.
+    def cookbook_maintainer_email(file)
+      fail ArgumentError, 'File cannot be nil or empty' if file.to_s.empty?
+
+      metadata_field(file, 'maintainer_email')
     end
 
     # The dependencies declared in cookbook metadata.
@@ -396,8 +424,7 @@ module FoodCritic
       doc, xml_node = xml_document(doc, xml_node)
 
       if node.respond_to?(:each)
-        # First child is the node name
-        node.drop(1).each do |child|
+        node.each do |child|
           if position_node?(child)
             xml_position_node(doc, xml_node, child)
           else
@@ -470,7 +497,7 @@ module FoodCritic
     end
 
     def patched_node_method?(meth, cookbook_dir)
-      return false if cookbook_dir.nil? || !Dir.exists?(cookbook_dir)
+      return false if cookbook_dir.nil? || !Dir.exist?(cookbook_dir)
 
       # TODO: Modify this to work with multiple cookbook paths
       cbk_tree_path = Pathname.new(File.join(cookbook_dir, '..'))
@@ -479,7 +506,7 @@ module FoodCritic
       libs.any? do |lib|
         !read_ast(lib).xpath(%Q{//class[count(descendant::const[@value='Chef'])
           > 0][count(descendant::const[@value='Node']) > 0]/descendant::def/
-          ident[@value='#{meth.to_s}']}).empty?
+          ident[@value='#{meth}']}).empty?
       end
     end
 
@@ -493,7 +520,7 @@ module FoodCritic
       source = if file.to_s.split(File::SEPARATOR).include?('templates')
                  template_expressions_only(file)
                else
-                 File.read(file)
+                 File.read(file).encode('utf-8', 'binary', :undef => :replace)
                end
       build_xml(Ripper::SexpBuilder.new(source).parse)
     end
@@ -550,7 +577,9 @@ module FoodCritic
     end
 
     def template_expressions_only(file)
-      exprs = Template::ExpressionExtractor.new.extract(File.read(file))
+      exprs = Template::ExpressionExtractor.new.extract(
+        File.read(file).encode('utf-8', 'binary', :undef => :replace)
+      )
       lines = Array.new(exprs.map { |e| e[:line] }.max || 0, '')
       exprs.each do |e|
         lines[e[:line] - 1] += ';' unless lines[e[:line] - 1].empty?
