@@ -1,6 +1,5 @@
 require 'optparse'
 require 'ripper'
-require 'rubygems'
 require 'set'
 
 module FoodCritic
@@ -10,18 +9,21 @@ module FoodCritic
 
     # The default version that will be used to determine relevant rules. This
     # can be over-ridden at the command line with the `--chef-version` option.
-    DEFAULT_CHEF_VERSION = '11.10.4'
+    DEFAULT_CHEF_VERSION = '12.11.18'
     attr_reader :chef_version
 
     # Perform a lint check. This method is intended for use by the command-line
     # wrapper. If you are programatically using foodcritic you should use
     # `#check` below.
-    def self.check(cmd_line)
+    def self.run(cmd_line)
       # The first item is the string output, the second is exit code.
       return [cmd_line.help, 0] if cmd_line.show_help?
       return [cmd_line.version, 0] if cmd_line.show_version?
       if !cmd_line.valid_grammar?
         [cmd_line.help, 4]
+      elsif cmd_line.list_rules?
+        listing = FoodCritic::Linter.new.list(cmd_line.options)
+        [listing, 0]
       elsif cmd_line.valid_paths?
         review = FoodCritic::Linter.new.check(cmd_line.options)
         [review, review.failed? ? 3 : 0]
@@ -30,6 +32,26 @@ module FoodCritic
       end
     end
 
+    # List the rules that are currently in effect.
+    #
+    # The `options` are a hash where the valid keys are:
+    #
+    # * `:include_rules` - Paths to additional rules to apply
+    # * `:search_gems - If true then search for custom rules in installed gems.
+    # * `:tags` - The tags to filter rules based on
+    def list(options = {})
+      options = setup_defaults(options)
+      @options = options
+      load_rules
+
+      if options[:tags].any?
+        @rules = active_rules(options[:tags])
+      end
+
+      RuleList.new(@rules)
+    end
+
+
     # Review the cookbooks at the provided path, identifying potential
     # improvements.
     #
@@ -53,16 +75,22 @@ module FoodCritic
       paths = specified_paths!(options)
 
       # Loop through each file to be processed and apply the rules
-      files_to_process(paths).each do |p|
+      files = files_to_process(paths)
 
+      if options[:progress]
+        puts "Checking #{files.count} files"
+      end
+
+      files.each do |p|
         relevant_tags = if options[:tags].any?
                           options[:tags]
                         else
                           cookbook_tags(p[:filename])
                         end
 
-        active_rules(relevant_tags).each do |rule|
+        progress = '.'
 
+        active_rules(relevant_tags).each do |rule|
           state = {
             path_type: p[:path_type],
             file: p[:filename],
@@ -79,6 +107,8 @@ module FoodCritic
 
           matches = remove_ignored(matches, state[:rule], state[:file])
 
+          progress = 'x' if matches.any?
+
           # Convert the matches into warnings
           matches.each do |match|
             warnings << Warning.new(state[:rule],
@@ -87,9 +117,14 @@ module FoodCritic
             matched_rule_tags << state[:rule].tags
           end
         end
+
+        putc progress if options[:progress]
+
         last_dir = cookbook_dir(p[:filename])
       end
 
+      puts '' if options[:progress]
+
       Review.new(paths, warnings)
     end
 
@@ -141,6 +176,7 @@ module FoodCritic
       matches.reject do |m|
         matched_file = m[:filename] || file
         (line = m[:line]) && File.exist?(matched_file) &&
+           !File.directory?(matched_file) &&
            ignore_line_match?(File.readlines(matched_file)[line - 1], rule)
       end
     end
@@ -152,6 +188,8 @@ module FoodCritic
       else
         false
       end
+    rescue
+      false
     end
 
     # Some rules are version specific.
