@@ -4,8 +4,7 @@ require 'rake/tasklib'
 module FoodCritic
   module Rake
     class LintTask < ::Rake::TaskLib
-      attr_accessor :name, :files
-      attr_writer :options
+      attr_accessor :name, :files, :options
 
       def initialize(name = :foodcritic)
         @name = name
@@ -15,24 +14,29 @@ module FoodCritic
         define
       end
 
-      def options
-        {
-          fail_tags: ['correctness'], # differs to default cmd-line behaviour
-          cookbook_paths: @files,
-          exclude_paths: ['test/**/*', 'spec/**/*', 'features/**/*'],
-          context: false,
-        }.merge(@options)
-      end
 
       def define
-        desc 'Lint Chef cookbooks' unless ::Rake.application.last_comment
+        desc 'Lint Chef cookbooks' unless ::Rake.application.last_description
         task(name) do
-          result = FoodCritic::Linter.new.check(options)
+          puts "Starting Foodcritic linting..."
+          result = FoodCritic::Linter.new.check(default_options.merge(options))
           printer = options[:context] ? ContextOutput.new : SummaryOutput.new
           printer.output(result) if result.warnings.any?
           abort if result.failed?
+          puts "Completed!"
         end
       end
+
+      private
+      def default_options
+        {
+          fail_tags: ['correctness'], # differs to default cmd-line behaviour
+          cookbook_paths: files,
+          exclude_paths: ['test/**/*', 'spec/**/*', 'features/**/*'],
+          context: false,
+          chef_version: FoodCritic::Linter::DEFAULT_CHEF_VERSION
+        }
+      end
     end
   end
 end
