@@ -22,7 +22,7 @@ rule 'FC002', 'Avoid string interpolation where not required' do
   recipe do |ast|
     ast.xpath(%q{//*[self::string_literal | self::assoc_new]/string_add[
       count(descendant::string_embexpr) = 1 and
-      count(tstring_content|string_add/tstring_content) = 0]})
+      count(string_add) = 0]})
   end
 end
 
@@ -194,9 +194,8 @@ rule 'FC014', 'Consider extracting long ruby_block to library' do
   end
 end
 
-rule 'FC015', 'Consider converting definition to a LWRP' do
+rule 'FC015', 'Consider converting definition to a Custom Resource' do
   tags %w(style definitions lwrp)
-  applies_to { |version| version >= gem_version('0.7.12') }
   cookbook do |dir|
     Dir[File.join(dir, 'definitions', '*.rb')].reject do |entry|
       ['.', '..'].include? entry
@@ -206,7 +205,6 @@ end
 
 rule 'FC016', 'LWRP does not declare a default action' do
   tags %w(correctness lwrp)
-  applies_to { |version| version >= gem_version('0.7.12') }
   resource do |ast, filename|
     unless ["//ident/@value='default_action'",
      "//def/bodystmt/descendant::assign/
@@ -218,9 +216,6 @@ end
 
 rule 'FC017', 'LWRP does not notify when updated' do
   tags %w(correctness lwrp)
-  applies_to do |version|
-    version >= gem_version('0.7.12')
-  end
   provider do |ast, filename|
 
     use_inline_resources = !ast.xpath('//*[self::vcall or self::var_ref]/ident
@@ -251,7 +246,6 @@ end
 
 rule 'FC018', 'LWRP uses deprecated notification syntax' do
   tags %w(style lwrp deprecated)
-  applies_to { |version| version >= gem_version('0.9.10') }
   provider do |ast|
     ast.xpath("//assign/var_field/ivar[@value='@updated']").map do |class_var|
       match(class_var)
@@ -297,7 +291,6 @@ end
 
 rule 'FC021', 'Resource condition in provider may not behave as expected' do
   tags %w(correctness lwrp)
-  applies_to { |version| version >= gem_version('0.10.6') }
   provider do |ast|
     find_resources(ast).map do |resource|
       condition = resource.xpath(%q{//method_add_block/
@@ -312,7 +305,6 @@ end
 
 rule 'FC022', 'Resource condition within loop may not behave as expected' do
   tags %w(correctness)
-  applies_to { |version| version >= gem_version('0.10.6') }
   recipe do |ast|
     ast.xpath("//call[ident/@value='each']/../do_block[count(ancestor::
               method_add_block/method_add_arg/fcall/ident[@value='only_if' or
@@ -359,7 +351,7 @@ end
 
 rule 'FC024', 'Consider adding platform equivalents' do
   tags %w(portability)
-  RHEL = %w(amazon centos redhat scientific)
+  RHEL = %w(amazon centos redhat scientific oracle)
   recipe do |ast, filename|
     next if Pathname.new(filename).basename.to_s == 'metadata.rb'
     metadata_path = Pathname.new(
@@ -391,7 +383,6 @@ end
 
 rule 'FC025', 'Prefer chef_gem to compile-time gem install' do
   tags %w(style deprecated)
-  applies_to { |version| version >= gem_version('0.10.10') }
   recipe do |ast|
     gem_install = ast.xpath("//stmts_add/assign[method_add_block[command/ident/
       @value='gem_package'][do_block/stmts_add/command[ident/@value='action']
@@ -410,7 +401,6 @@ end
 
 rule 'FC026', 'Conditional execution block attribute contains only string' do
   tags %w(correctness)
-  applies_to { |version| version >= gem_version('0.7.4') }
   recipe do |ast|
     find_resources(ast).map { |r| resource_attributes(r) }.map do |resource|
       [resource['not_if'], resource['only_if']]
@@ -482,9 +472,14 @@ end
 rule 'FC032', 'Invalid notification timing' do
   tags %w(correctness notifications)
   recipe do |ast|
+    valid_timings = if resource_attribute?('file', 'notifies_before') then
+      [:delayed, :immediate, :before]
+    else
+      [:delayed, :immediate]
+    end
     find_resources(ast).select do |resource|
       notifications(resource).any? do |notification|
-        ! [:delayed, :immediate].include? notification[:timing]
+        ! valid_timings.include? notification[:timing]
       end
     end
   end
@@ -618,7 +613,7 @@ rule 'FC041', 'Execute resource used to run curl or wget commands' do
   recipe do |ast|
     find_resources(ast, type: 'execute').select do |cmd|
       cmd_str = (resource_attribute(cmd, 'command') || resource_name(cmd)).to_s
-      (cmd_str.include?('curl ') || cmd_str.include?('wget '))
+      (cmd_str.match(/^curl.*(-o|>|--output).*$/) || cmd_str.include?('wget '))
     end
   end
 end
@@ -632,7 +627,6 @@ end
 
 rule 'FC043', 'Prefer new notification syntax' do
   tags %w(style notifications deprecated)
-  applies_to { |version| version >= gem_version('0.9.10') }
   recipe do |ast|
     find_resources(ast).select do |resource|
       notifications(resource).any? { |notify| notify[:style] == :old }
@@ -646,18 +640,25 @@ rule 'FC044', 'Avoid bare attribute keys' do
     declared = ast.xpath('//descendant::var_field/ident/@value').map do |v|
       v.to_s
     end
+
     ast.xpath('//assign/*[self::vcall or self::var_ref]
               [count(child::kw) = 0]/ident').select do |v|
+
+      local_declared = v.xpath("ancestor::*[self::brace_block or self::do_block]
+                                /block_var/descendant::ident/@value").map do |v|
+          v.to_s
+        end
+
       (v['value'] != 'secure_password') &&
-        !declared.include?(v['value']) &&
+        !(declared + local_declared).uniq.include?(v['value']) &&
         !v.xpath("ancestor::*[self::brace_block or self::do_block]/block_var/
                   descendant::ident/@value='#{v['value']}'")
     end
   end
 end
 
-rule 'FC045', 'Consider setting cookbook name in metadata' do
-  tags %w(annoyances metadata)
+rule 'FC045', 'Metadata does not contain cookbook name' do
+  tags %w(correctness metadata chef12)
   metadata do |ast, filename|
     unless ast.xpath('descendant::stmts_add/command/ident/@value="name"')
       [file_match(filename)]
@@ -679,7 +680,7 @@ rule 'FC046', 'Attribute assignment uses assign unless nil' do
 end
 
 rule 'FC047', 'Attribute assignment does not specify precedence' do
-  tags %w(attributes correctness)
+  tags %w(attributes correctness chef11)
   recipe do |ast|
     attribute_access(ast).map do |att|
       exclude_att_types = '[count(following-sibling::ident[
@@ -698,9 +699,14 @@ end
 rule 'FC048', 'Prefer Mixlib::ShellOut' do
   tags %w(style processes)
   recipe do |ast|
-    ast.xpath('//xstring_literal | //*[self::command or self::fcall]/
-      ident[@value="system"][count(following-sibling::args_add_block/
-      descendant::kw[@value="true" or @value="false"]) = 0]')
+    xstring_literal = ast.xpath('//xstring_literal')
+    next xstring_literal if xstring_literal.any?
+
+    ast.xpath('//*[self::command or self::fcall]/ident[@value="system"]').select do |x|
+      resource_name = x.xpath('ancestor::do_block/preceding-sibling::command/ident/@value')
+      next false if resource_name.any? && resource_name.all? { |r| resource_attribute?(r.to_s, 'system') }
+      next x.xpath('count(following-sibling::args_add_block/descendant::kw[@value="true" or @value="false"]) = 0')
+    end
   end
 end
 
@@ -739,3 +745,133 @@ rule 'FC051', 'Template partials loop indefinitely' do
     end.map { |t| file_match(t) }
   end
 end
+
+rule 'FC052', 'Metadata uses the unimplemented "suggests" keyword' do
+  tags %w(style metadata)
+  metadata do |ast, filename|
+    ast.xpath(%Q(//command[ident/@value='suggests']))
+  end
+end
+
+rule 'FC053', 'Metadata uses the unimplemented "recommends" keyword' do
+  tags %w(style metadata)
+  metadata do |ast, filename|
+    ast.xpath(%Q(//command[ident/@value='recommends']))
+  end
+end
+
+# NOTE: FC054 was yanked and should be considered reserved, do not reuse it
+
+rule 'FC055', 'Ensure maintainer is set in metadata' do
+  tags %w(correctness metadata)
+  metadata do |ast, filename|
+    [file_match(filename)] unless field(ast, 'maintainer').any?
+  end
+end
+
+rule 'FC056', 'Ensure maintainer_email is set in metadata' do
+  tags %w(correctness metadata)
+  metadata do |ast, filename|
+    [file_match(filename)] unless field(ast, 'maintainer_email').any?
+  end
+end
+
+rule 'FC057', 'Library provider does not declare use_inline_resources' do
+  tags %w(correctness)
+  applies_to do |version|
+    version >= gem_version('11.0.0')
+  end
+  library do |ast, filename|
+    ast.xpath('//const_path_ref/const[@value="LWRPBase"]/..//const[@value="Provider"]/../../..').select do |x|
+      x.xpath('//*[self::vcall or self::var_ref]/ident[@value="use_inline_resources"]').empty?
+    end
+  end
+end
+
+rule 'FC058', 'Library provider declares use_inline_resources and declares #action_<name> methods' do
+  tags %w(correctness)
+  applies_to do |version|
+    version >= gem_version('11.0.0')
+  end
+  library do |ast, filename|
+    ast.xpath('//const_path_ref/const[@value="LWRPBase"]/..//const[@value="Provider"]/../../..').select do |x|
+      x.xpath('//*[self::vcall or self::var_ref]/ident[@value="use_inline_resources"]').length > 0 &&
+        x.xpath(%Q(//def[ident[contains(@value, 'action_')]])).length > 0
+    end
+  end
+end
+
+rule 'FC059', 'LWRP provider does not declare use_inline_resources' do
+  tags %w(correctness)
+  applies_to do |version|
+    version >= gem_version('11.0.0')
+  end
+  provider do |ast, filename|
+    use_inline_resources = !ast.xpath('//*[self::vcall or self::var_ref]/ident
+      [@value="use_inline_resources"]').empty?
+    unless use_inline_resources
+      [file_match(filename)]
+    end
+  end
+end
+
+rule 'FC060', 'LWRP provider declares use_inline_resources and declares #action_<name> methods' do
+  tags %w(correctness)
+  applies_to do |version|
+    version >= gem_version('11.0.0')
+  end
+  provider do |ast, filename|
+    use_inline_resources = !ast.xpath('//*[self::vcall or self::var_ref]/ident
+      [@value="use_inline_resources"]').empty?
+    if use_inline_resources
+      ast.xpath(%Q(//def[ident[contains(@value, 'action_')]]))
+    end
+  end
+end
+
+rule 'FC061', 'Valid cookbook versions are of the form x.y or x.y.z' do
+  tags %w{metadata correctness}
+  metadata do |ast, filename|
+    # matches a version method with a string literal with no interpolation
+    ver = ast.xpath('//command[ident/@value="version"]/args_add_block/args_add/string_literal[not(.//string_embexpr)]//tstring_content/@value')
+    if !ver.empty? && ver.to_s !~ /\A\d+\.\d+(\.\d+)?\z/
+      [file_match(filename)]
+    end
+  end
+end
+
+rule 'FC062', 'Cookbook should have version metadata' do
+  tags %w{metadata}
+  metadata do |ast, filename|
+    [file_match(filename)] unless field(ast, 'version').any?
+  end
+end
+
+rule 'FC063', 'Cookbook incorrectly depends on itself' do
+  tags %w(metadata correctness)
+  metadata do |ast, filename|
+    name = cookbook_name(filename)
+    ast.xpath(%Q(//command[ident/@value='depends']/
+              descendant::tstring_content[@value='#{name}']))
+  end
+end
+
+rule 'FC064', 'Ensure issues_url is set in metadata' do
+  tags %w(metadata supermarket chef12)
+  applies_to do |version|
+    version >= gem_version('12.0.0')
+  end
+  metadata do |ast, filename|
+    [file_match(filename)] unless field(ast, 'issues_url').any?
+  end
+end
+
+rule 'FC065', 'Ensure source_url is set in metadata' do
+  tags %w(metadata supermarket chef12)
+  applies_to do |version|
+    version >= gem_version('12.0.0')
+  end
+  metadata do |ast, filename|
+    [file_match(filename)] unless field(ast, 'source_url').any?
+  end
+end
